aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/rosa/python.go
diff options
context:
space:
mode:
authorOphestra <cat@gensokyo.uk>2026-09-05 05:44:33 +0900
committerOphestra <cat@gensokyo.uk>2026-09-05 06:25:41 +0900
commit5a32f8f9b2f2540495e79cb39ce4a6861553fe79 (patch)
tree47b25144af5edead669b615f3abcc51aedd81096 /internal/rosa/python.go
parent871c701fdbce4a3d43e6e8edc436a2ae93322540 (diff)
internal/rosa: separate native tools from libraries
This removes most redundant runtime arguments and is useful for cross-compilation. Signed-off-by: Ophestra <cat@gensokyo.uk>
Diffstat (limited to 'internal/rosa/python.go')
-rw-r--r--internal/rosa/python.go9
1 files changed, 6 insertions, 3 deletions
diff --git a/internal/rosa/python.go b/internal/rosa/python.go
index 96f7714c..54022bd7 100644
--- a/internal/rosa/python.go
+++ b/internal/rosa/python.go
@@ -25,14 +25,17 @@ type PipHelper struct {
var _ Helper = new(PipHelper)
-// extra returns python, or pytest if defaults are assumed.
-func (attr *PipHelper) extra() P {
+// tools returns python and pytest if defaults are assumed.
+func (attr *PipHelper) tools() P {
if attr == nil || (!attr.SkipCheck && attr.Check == "") {
- return P{_pythonPyTest}
+ return P{_python, _pythonPyTest}
}
return P{_python}
}
+// inputs returns python.
+func (*PipHelper) inputs() P { return P{_python} }
+
// wantsChmod returns true.
func (*PipHelper) wantsChmod() bool { return true }